function [Cp, V, gamma] = panelmethod(X, Y, alpha)

% alpha is angle of attack

% m panels, and m+1 points.
% m is equal to the length of x - 1 because there will be 1 extra
% panel, which will cause a fence post error and the minus 1
% compensates for that
% loop using panel method to determine control point location and panel
% length using every X and Y element.

m = length(X)-1;
for i = 1:m
    % panel length
    S(i)=sqrt((X(i+1)-X(i))^2+(Y(i+1)-Y(i))^2);
    
    % control points
    % for each i, x and y represent the sums of each X and Y NACA point and
    % the next one FIX
    x(i)=0.5*(X(i)+X(i+1));
    y(i)=0.5*(Y(i)+Y(i+1));
    % orientation of panel
    th(i)=atan2(Y(i+1)-Y(i),(X(i+1)-X(i)));
end


for i = 1:m
    for j = 1:m
        % defined parameters
        % these are what the constants show in some of the equations are
        % defined as.
        % these constants are functions of the coordinates of the ith
        % control point, those of the boundary points of the jth vortex
        % panel, and the orientation angles of both ith and jth panels.
        % They can be computed for all possible values of i and j once the
        % panel geometry is specified.
        
        A = - (x(i) - X(j)) * cos (th (j)) - (y(i)- Y(j)) * sin(th(j));
        B =   (x(i) - X(j))^2 + (y(i) - Y(j))^2;
        C =   sin(th(i) - th(j));
        D =   cos(th(i)-th(j));
        E =   (x(i) - X(j)) * sin(th(j)) - (y(i) - Y(j))  * cos(th(j));
        F =   log(1 + (S(j)^2 + 2 * A * S(j))/B);
        G =   atan2(E * S(j),(B + A * S(j)));
        P =   (x(i) - X(j)) * sin(th(i) - 2 * th(j)) + (y(i) - Y(j)) * ...
            cos(th(i)-2*th(j));
        Q =   (x(i) - X(j)) * cos(th(i) - 2 * th(j)) - (y(i) - Y(j)) * ...
            sin(th(i)-2*th(j));
        
        
        % Cn and Cn2 are 1 and -1 because for i equals j the coefficients have
        % simplified values which describe the self - induced normal velocity at
        % the ith control point
        if i == j
            Cn2(i,j) =   1;
            Cn1(i,j) = - 1;
            Ct1(i,j) =   0.5*pi;
            Ct2(i,j) =   0.5*pi;
        else
            % these matrix are aquired to emphasiZe that there is no flow going
            % through the paneL
            Cn2(i,j) =   D + 0.5 * Q * F/S(j) - (A * C + D * E) * G/S(j);
            Cn1(i,j) =       0.5 * D * F + C  * G - Cn2(i,j);
            Ct2(i,j) =   C + 0.5 * P * F/S(j) + (A * D - C * E) * G/S(j);
            Ct1(i,j) =       0.5 * C * F - D  * G - Ct2(i,j);
        end
    end
end

% An matrix
% acquired from equation 5.47
for i = 1:m+1
    for j = 2:m
        if i < m+1
            
            % these are just cases when i is smaller than m + 1 that are
            % sufficient enough to solve for the (m +1) unknowns of gamma
            % which are the circulation densities
            % these equations are just arranged differently than from
            % equation 5.47 to meet special cases
            
            An(i,1)   = Cn1(i,1);
            
            An(i,j)   = Cn1(i,j)  + Cn2(i,j-1);
            
            An(i,m+1) = Cn2(i,m);
            
            RHS(i)    = sin(th(i) - alpha);
        elseif i == m+1
            % may be called the normal-velocity influence coefficients
            % representing the influences of gammaI on the normal velocity
            % at the ith control point.
            % gammaI is reffered to from equation 5.47
            
            % the first two equtions on the bottom of this comment are the
            % first and last entry for i = m + 1
            An(i,1)   = 1;
            
            An(i,m+1) = 1;
            
            An(i,j)   = 0;
            
            RHS(i)    = 0;
        end
    end
end


%At matrix
for i = 1:m
    for j = 2:m
        % tangential-velocity influence coefficient defined below:
        At(i,1) = Ct1(i,1);
        
        At(i,j) = Ct1(i,j) + Ct2(i,j-1);
    end
    % this is only needed for i elements thats why the equation below is
    % writtien outside for the for loop j = 2:m
    At(i,m+1)= Ct2(i,m);
end

% solving for gamma
RHS   = RHS';
g     = An\RHS;
gamma = g;

for i = 1:m
    % the sum of Ag is At times gamma
    sumAg = At * g;
    
    
    % The expression in the parentheses following the summation symbol has
    % the physical meaning of the tangential velocity at the ith conrtol
    % point induced by the vorticies distributed on the jth panel.
    V (i) = cos(th(i) - alpha) + sumAg (i);
end
% compute pressure coefficients
Cp = 1 - V.^2;
