% Given a L1300 series, this script models an airfoil and its
% aerodynamic properties by plotting an airfoil shape against an array
% of streamlines with various angles of attack at the leading edge
% and through the upper and lower surfaces.

close all
clear all
clc
% first defining as array of L1300Points, then splitting the columns
% into variables X and Y.

L1003Points

% defining angle of attack as alpha to be used in panelmethod function
% (not the same as AoA later).


% alpha is in radians
alpha = pi/15;

% defining uniform flow

% velocity is in meters/second
V_inf = 15;

% define X, Y, Cp, V, gamma, and array sizes.

% xxxx used as temp veriable to print variable lengths
xxxx = sprintf('The length of X is %d', length(X));
disp(xxxx)



% Cp = pressure coefficient
[Cp,V,gamma] = panelmethod(X,Y,alpha);
xxxx = sprintf('The length of Cp is %d', length(Cp));
disp(xxxx)
xxxx = sprintf('The length of V is %d', length(V));
disp(xxxx)
xxxx = sprintf('The length of gamma is %d', length(gamma));
disp(xxxx)



% determining control point location and panel length using every X and Y
% element. using (-1) to avoid indexing error.

m = length(X)-1;
for i = 1:m
    % panel length
    S(i)=sqrt((X(i+1)-X(i))^2+(Y(i+1)-Y(i))^2);
    % control points
    % for each i, x and y represent the sums of each X(i) and Y(i) point
    % and their respective X(i+1) and Y (i+1) points.
    x(i)=0.5*(X(i)+X(i+1));
    y(i)=0.5*(Y(i)+Y(i+1));
    % orientation of panel
    theta(i)=atan2(Y(i+1)-Y(i),(X(i+1)-X(i)));
end

% S = distance between each point using the distance formula.
% x and y represent the ith control point
% theta = angle between each panel and the x-axis.
xxxx = sprintf('the length of S is %d', length(S));
disp(xxxx)
xxxx = sprintf('the length of x is %d', length(x));
disp(xxxx)
xxxx = sprintf('the length of y is %d', length(y));
disp(xxxx)


% Creating mesh of Xm and Ym, both 101x141 arrays.
[Xm,Ym] = meshgrid(-0.2:0.01:1.2,-0.5:0.01:0.5);

% Xm and Ym are two arbitrary meshgrids that just work
xxxx = sprintf('the length of the first column in Xm is %d', size(Xm,1));
disp(xxxx)
xxxx = sprintf('the length of the first column in Ym is %d', size(Ym,1));
disp(xxxx)
xxxx = sprintf('the length of the second column in Xm is %d', size(Ym,2));
disp(xxxx)
xxxx = sprintf('the length of the second column in Ym is %d', size(Ym,2));
disp(xxxx)


% Negative angle of attack used to create a downward tilt of the
% airfoil.
% AoA is in radians.
AoA = -alpha;

% Setting rotation variable to be used in direction cosine matrix
% as 2x2 array directly related to AoA.
rotArray = [cos(AoA) -sin(AoA);sin(AoA) cos(AoA)];


% loop to create direction cosine matrix using evey x and y element.
for j=1:m
    F=[x(j);y(j)];
    rotF=rotArray*F;
    xx(j)=rotF(1);
    yy(j)=rotF(2);
    
    % xx is a 1xj array of every x element times the first column of
    % rotArray.
    % yy is a 1xj array of every y element times the second column of
    % rotArray.
end


% defining a variable to use equation 5.48 and intiially equal 0, then loop
% is used to add each m equation value and each NEXT m equation value.
% this ultimately results in array vortex_psi with the same dimensions
% as meshgrid.

% initial is a temporary variable used to set intitial velocity as 0
initial = 0;
vortexPsi = 0;
for i = 1:m
    initial = 0.5*V_inf*gamma(i)*S(i)*log((Xm - xx(i)).^2 + ...
        (Ym - yy(i)).^2);
    vortexPsi = vortexPsi + initial;
end
xxxx = sprintf('the number of rows in vortexPsi is %d',    ...
    size (vortexPsi,1));
disp(xxxx)
xxxx = sprintf('the number of columns in vortexPsi is %d', ...
    size (vortexPsi,2));
disp(xxxx)


% defining psi which finishes equation 5.49
psi = V_inf*Ym*cos(alpha) + vortexPsi;




% using the same for loop as before, but this time to create the x and
% y coords (Xa, Ya) to plot the actual airfoil.

for j=1:length(X)
    F=[X(j);Y(j)];
    rotF=rotArray*F;
    Xa(j)=rotF(1);
    Ya(j)=rotF(2);
    % Xa is a 1xj array of every x element times the first column of
    % rotArray
    % Ya is a 1xj array of every y element times the second column of
    % rotArray.
end


% adding airfoil

% uncomment next three lines for the original airfoil surface
% plot(Xa,Ya,'k','linewidth',2)
% hold on
% axis equal


for j=1:length(X)
    F=[X(j);Y(j)];
    rotF=rotArray*F;
    R(:,j)=rotF;
    Xa=R(1,:);
    Ya=R(2,:);
end
[Xm,Ym]=meshgrid(-.2:.01:1.2,-.5:0.01:0.5);

% streamline contours
contour(Xm,Ym,psi,35,'b');
hold on


% reusing some variables
clear F rotF R Xa Ya


% rotate airfoil coordinates
for j=1:length(x)
    F=[x(j);y(j)];
    rotF=rotArray*F;
    R(:,j)=rotF;
    xBlade=R(1,:);
    yBlade=R(2,:);
end


% initialize array to zeros
contourCp = zeros(1,length(X));

% create array of pressure coefficient for contour
contourCp = Cp;

% create grid on airfoil blade
[A,B] = meshgrid(xBlade,yBlade);

% trick to only apply contour on arifoil surface
C = diag(contourCp,0);

% tweak levels
D = linspace(min(Cp)/5,max(Cp),100);
caxis([min(Cp)/5 max(Cp)])

%make contour plot
contour(A,B,C,D,'LineWidth',0.5)
axis equal
hold on

% make colorbar
colorbar
% horizontal title
xlabel('x (m)')
% vertical title
ylabel('y (m)')
c=colorbar;
% horizontal title
ylabel(c,'C_p')
